% This script models anisotropy of a sandy shale model
% Multiple realizations at the well location

clear;clc;close all
addpath('/net/server/homes/sep/myfusan/Report/149-Rockphy/Matlab/');
addpath('/net/server/homes/sep/myfusan/Research/RockPhy/Matlab/subroutine/');


%% read in 
fid = fopen('/net/server/homes/sep/myfusan/Research/RockPhy/welllog/well2.vshale.H@','r','s');
vshale = fread(fid, inf,'*float');
vshale (vshale>1) = 1;
fid = fopen('/net/server/homes/sep/myfusan/Research/RockPhy/welllog/well2.phi.H@','r','s');
poro = fread(fid, inf,'*float');

fid = fopen('/net/server/homes/sep/myfusan/Research/RockPhy/welllog/well2.pillite.H@','r','s');
pillite = fread(fid, inf,'*float');

%% define parameters
W200_exp = 0.8:0.1:1.2;
W400_exp = 1;
phi_c    = 0.4:0.05:0.6;
phi_d    = 0.05;

nw = length(W200_exp);
np = length(phi_c);
nd = length(vshale);
epsilonall = zeros(nd,nw,np);
deltaall   = zeros(nd,nw,np);


for ip = 1:np
    poro(poro>phi_c(ip)) = phi_c(ip);
    for iw = 1:nw
        [epsilon, delta] = dem_sandyshale(vshale,poro,pillite,W200_exp(iw),W400_exp,phi_c(ip),phi_d);
        epsilonall(:,iw,ip) = epsilon;
        deltaall  (:,iw,ip) = delta;
    end
    ip
end

save sandyshale_random epsilonall deltaall
%% plot the pdf
deps = 0.01;
ddel = 0.01;
nbin1 = 0:deps:1.0;
nbin2 = 0:ddel:0.6;

epsilonall(deltaall<0)=[];
deltaall(deltaall<0)=[];
deltaall(epsilonall>1)=[];
epsilonall(epsilonall>1)=[];
[inclu_pdf,inclu_nbin1,inclu_nbin2] = pdf2d([epsilonall(:),deltaall(:)],nbin1,nbin2);
hf=figure;
imagesc(nbin1,nbin2,inclu_pdf);
axis xy
xlabel('Epsilon')
ylabel('Delta')
colorbar

print(hf,'-dpdf',['/net/server/homes/sep/myfusan/Research/RockPhy/Fig/sandyshale_pdf.pdf'])

