clc;close all; clear
%% read the well
well2 = loadlas('177114129700_Orig_Edit_RckPhys.las');

%% shallow part of the log
shallow_gr = well2.grr;
shallow_phi = well2.npor;
shallow_depth = well2.depth;
shallow_vp = well2.dt_ed5;

shallow_depth(isnan(shallow_gr)) = [];
shallow_phi  (isnan(shallow_gr)) = [];
shallow_vp   (isnan(shallow_gr)) = [];
shallow_gr   (isnan(shallow_gr)) = [];

shallow_depth(isnan(shallow_phi)) = [];
shallow_vp   (isnan(shallow_phi)) = [];
shallow_gr   (isnan(shallow_phi)) = [];
shallow_phi  (isnan(shallow_phi)) = [];

% convert velocity to m/s
shallow_vp = 1./shallow_vp * 0.3048 * 1e+6; 
% compute vshale from gr
shallow_vshale = (shallow_gr - 30) ./(110-30);
shallow_vshale(shallow_vshale>1) = 1;
shallow_vshale(shallow_vshale<0) = 0;
% calibrate porosity
shallow_phi = shallow_phi - shallow_vshale*0.3;
shallow_phi(shallow_phi<0) = 0;


%% deep part of the log
deep_gr = well2.grs;
deep_phi = well2.tnph;
deep_depth = well2.depth;
deep_vp = well2.dt_ed5;

deep_depth(isnan(deep_gr)) = [];
deep_phi  (isnan(deep_gr)) = [];
deep_vp   (isnan(deep_gr)) = [];
deep_gr   (isnan(deep_gr)) = [];

deep_depth(isnan(deep_phi)) = [];
deep_vp   (isnan(deep_phi)) = [];
deep_gr   (isnan(deep_phi)) = [];
deep_phi  (isnan(deep_phi)) = [];

deep_vp = 1./deep_vp * 0.3048 * 1e+6; 
deep_vshale = (deep_gr - 30) ./(100-30);
deep_vshale(deep_vshale>1) = 1;
deep_vshale(deep_vshale<0) = 0;
% calibrate porosity
deep_phi = deep_phi - deep_vshale*0.35;
deep_phi(deep_phi<0) = 0;

%% cat two parts together
regwell2.depth = [shallow_depth ;deep_depth(4:end)];
regwell2.phi = [shallow_phi;deep_phi(4:end)];
regwell2.gr  = [shallow_gr ;deep_gr(4:end) ];
regwell2.vshale = [shallow_vshale ;deep_vshale(4:end)];
regwell2.vp = [shallow_vp ;deep_vp(4:end)];
regwell2.rho = interp1(well2.depth,well2.rhogard,regwell2.depth);


%%

n1 = length(regwell2.depth);
o1 = min(regwell2.depth)*0.3048;
d1 = (regwell2.depth(2)-regwell2.depth(1))*0.3048;

fid = fopen('well2.vshale.H@','w','s');
count = fwrite(fid, regwell2.vshale,'real*4','s');
fclose(fid);

fid = fopen('well2.vshale.H','w');
fprintf(fid,'n1=%d o1=%f d1=%f ',n1,o1,d1);
fprintf(fid,'label1=depth(m)\n');
fprintf(fid,'n2=1 o2=0 d2=1\n');
fprintf(fid,'n3=1 o3=0 d3=1\n');
fprintf(fid,'in=./well2.vshale.H@');
fclose(fid);

fid = fopen('well2.phi.H@','w','s');
count = fwrite(fid, regwell2.phi,'real*4','s');
fclose(fid);

fid = fopen('well2.phi.H','w');
fprintf(fid,'n1=%d o1=%f d1=%f ',n1,o1,d1);
fprintf(fid,'label1=depth(m)\n');
fprintf(fid,'n2=1 o2=0 d2=1\n');
fprintf(fid,'n3=1 o3=0 d3=1\n');
fprintf(fid,'in=./well2.phi.H@');
fclose(fid);


fid = fopen('well2.vp.H@','w','s');
count = fwrite(fid, regwell2.vp,'real*4','s');
fclose(fid);

fid = fopen('well2.vp.H','w');
fprintf(fid,'n1=%d o1=%f d1=%f ',n1,o1,d1);
fprintf(fid,'label1=depth(m)\n');
fprintf(fid,'n2=1 o2=0 d2=1\n');
fprintf(fid,'n3=1 o3=0 d3=1\n');
fprintf(fid,'in=./well2.vp.H@');
fclose(fid);

%%  create synthetic seismograms
w = sourcewvlt;
wvlt = interp(w(1:200),4);
impd = regwell2.vp .* regwell2.rho;
rflt = diff(impd)./impd(2:end);
seis = conv(rflt, wvlt);
dept = regwell2.depth(2:end);

fid = fopen('well2.seis.H@','w','s');
count = fwrite(fid, seis,'real*4','s');
fclose(fid);

fid = fopen('well2.seis.H','w');
fprintf(fid,'n1=%d o1=%f d1=%f ',n1-1,o1+d1,d1);
fprintf(fid,'label1=depth(m)\n');
fprintf(fid,'n2=1 o2=0 d2=1\n');
fprintf(fid,'n3=1 o3=0 d3=1\n');
fprintf(fid,'in=./well2.seis.H@');
fclose(fid);




