clear;clc; close all
addpath('/net/server/homes/sep/myfusan/Report/149-Rockphy/Matlab/');

fid = fopen('/net/server/myfusan/rp149/rock/middleeps.H@','r','s');
middleeps = fread(fid, 4398000,'*float');
middleeps = middleeps * 0.6;

fid = fopen('/net/server/myfusan/rp149/rock/middledel.H@','r','s');
middledel = fread(fid, 4398000,'*float');
middledel = middledel * 0.6;

fid = fopen('/net/server/myfusan/rp149/rock/middlevp.H@','r','s');
vp = fread(fid, 439800,'*float');
middlevp = [vp; vp; vp; vp; vp; vp; vp; vp; vp; vp];

fclose all

%% change parameterization
middlevn  = middlevp .* sqrt(1+2*middledel);
middleeta = (middleeps - middledel) ./(1+2*middledel);
middleueta = (middleeps + middledel);

middleeps(middleeta<0) = [];
middledel(middleeta<0) = [];
middlevp(middleeta<0) = [];
middlevn(middleeta<0) = [];
middleueta(middleeta<0) = [];
middleeta(middleeta<0) = [];

lines_ed=linspace(1e-08,3e-4,20);
lines_ve=linspace(9e-06,2e-3,20);
lines_vd=linspace(9e-06,2e-3,20);
%% plot v_v epsilon delta pdfs
deps=0.005;
ddel=0.005;
dvel=500;
nbin1=0:deps:0.8;
nbin2=-0.05:ddel:0.4;
nbin3=1000:dvel:4500;

[middle_ed_pdf,ed_nbin1,ed_nbin2] = pdf2d([middleeps, middledel],nbin1,nbin2);
[middle_ve_pdf,ve_nbin3,ve_nbin1] = pdf2d([middlevp,  middleeps],nbin3,nbin1);
[middle_vd_pdf,vd_nbin3,vd_nbin2] = pdf2d([middlevp,  middledel],nbin3,nbin2);


hf=figure(1);
subplot(2,3,4)
contour(ve_nbin1,ve_nbin3,middle_ve_pdf,lines_ve)
% ylim([500 5000])
% xlim([0 0.5])
title('v_v - \epsilon pdf')
title('(d)')
xlabel('\epsilon')
ylabel('v_v')


subplot(2,3,5)
contour(vd_nbin2,vd_nbin3,middle_vd_pdf,lines_vd)
% ylim([500 5000])
% xlim([0 0.2])
title('v_v - \delta pdf')
title('(e)')
xlabel('\delta')
ylabel('v_v')

subplot(2,3,6)
contour(ed_nbin2,ed_nbin1,middle_ed_pdf,lines_ed)
ylim([0 0.8])
xlim([0 0.4])
title('\epsilon - \delta pdf')
title('(f)')
xlabel('\delta')
ylabel('\epsilon')

subplot(2,3,1)
imagesc(ve_nbin1,ve_nbin3,middle_ve_pdf)
title('v_v - \epsilon pdf')
title('(a)')
axis xy
xlabel('\epsilon')
ylabel('v_v')

subplot(2,3,2)
imagesc(vd_nbin2,vd_nbin3,middle_vd_pdf)
title('v_v - \delta pdf')
title('(b)')
axis xy
xlabel('\delta')
ylabel('v_v')

subplot(2,3,3)
imagesc(ed_nbin2,ed_nbin1,middle_ed_pdf)
title('\epsilon - \delta pdf')
title('(d)')
ylim([0 0.8])
xlim([0 0.4])
axis xy
xlabel('\delta')
ylabel('\epsilon')
print(hf,'-dpdf',['/net/server/homes/sep/myfusan/Report/149-Rockphy/Fig/model-vvepsdel.pdf'])

%% plot v_n eta uneta pdfs
deta=0.005;
dueta=0.005;
dvel=500;
nbin1=0:deta:0.6;
nbin2=0.:dueta:1.;
nbin3=1000:dvel:4500;

[middle_ed_pdf,ed_nbin1,ed_nbin2] = pdf2d([middleeta, middleueta],nbin1,nbin2);
[middle_ve_pdf,ve_nbin3,ve_nbin1] = pdf2d([middlevn,  middleeta ],nbin3,nbin1);
[middle_vd_pdf,vd_nbin3,vd_nbin2] = pdf2d([middlevn,  middleueta],nbin3,nbin2);

hf=figure(2);
subplot(2,3,4)
contour(ve_nbin1,ve_nbin3,middle_ve_pdf,lines_ve)
% ylim([500 5000])
% xlim([0 0.5])
title('v_n - \eta pdf')
title('(d)')
xlabel('\eta')
ylabel('v_n')


subplot(2,3,5)
contour(vd_nbin2,vd_nbin3,middle_vd_pdf,lines_vd)
% ylim([500 5000])
% xlim([0 0.2])
title('v_n - \eta_\perp pdf')
title('(e)')
xlabel('\eta_\perp')
ylabel('v_n')

subplot(2,3,6)
contour(ed_nbin2,ed_nbin1,middle_ed_pdf,lines_ed)
%ylim([0 0.6])
%xlim([0 0.7])
title('\eta - \eta_\perp pdf')
title('(f)')
xlabel('\eta_\perp')
ylabel('\eta')

subplot(2,3,1)
imagesc(ve_nbin1,ve_nbin3,middle_ve_pdf)
title('v_n - \eta pdf')
title('(a)')
axis xy
xlabel('\eta')
ylabel('v_n')

subplot(2,3,2)
imagesc(vd_nbin2,vd_nbin3,middle_vd_pdf)
title('v_n - \eta_\perp pdf')
title('(b)')
axis xy
xlabel('\eta_\perp')
ylabel('v_n')

subplot(2,3,3)
imagesc(ed_nbin2,ed_nbin1,middle_ed_pdf)
title('\eta - \eta_\perp pdf')
title('(c)')
%ylim([0 0.6])
%xlim([0 0.7])
axis xy
xlabel('\eta_\perp')
ylabel('\eta')
print(hf,'-dpdf',['/net/server/homes/sep/myfusan/Report/149-Rockphy/Fig/model-vnetauneta.pdf'])

%% plot data covariance vn eta uneta
deta=0.001;
dueta=0.001;
dvel=100;
nbin1=0:deta:0.6;
nbin2=0:dueta:1;
nbin3=1000:dvel:4500;

n1 = length(nbin1);
n2 = length(nbin2);
n3 = length(nbin3);

ic1 = (0.2-nbin1(1))/deta + 1;
ic2 = (0.4-nbin2(1))/dueta + 1;
ic3 = (2500-nbin3(1))/dvel + 1;

data_ed_pdf = zeros(n1,n2);
data_ve_pdf = zeros(n3,n1);
data_vd_pdf = zeros(n3,n2);

theta = 1./180*pi;
sigma_x = 50; 
sigma_y = 5000;
a = cos(theta)^2/2/sigma_x^2 + sin(theta)^2/2/sigma_y^2;
b = -sin(2*theta)/4/sigma_x^2 + sin(2*theta)/4/sigma_y^2 ;
c = sin(theta)^2/2/sigma_x^2 + cos(theta)^2/2/sigma_y^2;

for i=1:n1
    for j = 1:n2
        data_ed_pdf(i,j) = exp( - (a*(i-ic1).^2 + 2*b*(i-ic1).*(j-ic2) + c*(j-ic2).^2));
    end
end

theta = 0.;
sigma_x = 3; 
sigma_y = 300;
a = cos(theta)^2/2/sigma_x^2 + sin(theta)^2/2/sigma_y^2;
b = -sin(2*theta)/4/sigma_x^2 + sin(2*theta)/4/sigma_y^2 ;
c = sin(theta)^2/2/sigma_x^2 + cos(theta)^2/2/sigma_y^2;

for i=1:n3
    for j = 1:n1
        data_ve_pdf(i,j) = exp( - (a*(i-ic3).^2 + 2*b*(i-ic3).*(j-ic1) + c*(j-ic1).^2));
    end
end

theta = 0.;
sigma_x = 3; 
sigma_y = 1000;
a = cos(theta)^2/2/sigma_x^2 + sin(theta)^2/2/sigma_y^2;
b = -sin(2*theta)/4/sigma_x^2 + sin(2*theta)/4/sigma_y^2 ;
c = sin(theta)^2/2/sigma_x^2 + cos(theta)^2/2/sigma_y^2;

for i=1:n3
    for j = 1:n2
        data_vd_pdf(i,j) = exp( - (a*(i-ic3).^2 + 2*b*(i-ic3).*(j-ic2) + c*(j-ic2).^2));
    end
end

data_ed_pdf = data_ed_pdf ./ sum(sum(data_ed_pdf));
data_ve_pdf = data_ve_pdf ./ sum(sum(data_ve_pdf));
data_vd_pdf = data_vd_pdf ./ sum(sum(data_vd_pdf));

hf=figure(4);
subplot(2,3,4)
contour(nbin1,nbin3,data_ve_pdf,20)
% ylim([500 5000])
% xlim([0 0.5])
title('v_n - \eta pdf')
title('(d)')
xlabel('\eta')
ylabel('v_n')


subplot(2,3,5)
contour(nbin2,nbin3,data_vd_pdf,20)
% ylim([500 5000])
% xlim([0 0.2])
title('v_n - \eta_\perp pdf')
title('(e)')
xlabel('\eta_\perp')
ylabel('v_n')

subplot(2,3,6)
contour(nbin2,nbin1,data_ed_pdf,20)
%ylim([0 0.5])
%xlim([0 0.2])
title('\eta - \eta_\perp pdf')
title('(f)')
xlabel('\eta_\perp')
ylabel('\eta')

subplot(2,3,1)
imagesc(nbin1,nbin3,data_ve_pdf)
title('v_n - \eta pdf')
title('(a)')
axis xy
xlabel('\eta')
ylabel('v_n')

subplot(2,3,2)
imagesc(nbin2,nbin3,data_vd_pdf)
title('v_n - \eta_\perp pdf')
title('(b)')
axis xy
xlabel('\eta_\perp')
ylabel('v_n')

subplot(2,3,3)
imagesc(nbin2,nbin1,data_ed_pdf)
title('\eta - \eta_\perp pdf')
title('(c)')
%ylim([0 0.5])
%xlim([0 0.2])
axis xy
xlabel('\eta_\perp')
ylabel('\eta')
print(hf,'-dpdf',['/net/server/homes/sep/myfusan/Report/149-Rockphy/Fig/data_vnetauneta.pdf'])

%% plot data covariance vv epsilon delta
deps=0.001;
ddel=0.001;
dvel=100;
nbin1=0:deps:0.8;
nbin2=-0.05:ddel:0.4;
nbin3=1000:dvel:4500;

n1 = length(nbin1);
n2 = length(nbin2);
n3 = length(nbin3);

ic1 = (0.32-nbin1(1))/deps + 1;
ic2 = (0.08-nbin2(1))/ddel + 1;
ic3 = (2321-nbin3(1))/dvel + 1;

data_ed_pdf = zeros(n1,n2);
data_ve_pdf = zeros(n3,n1);
data_vd_pdf = zeros(n3,n2);

theta = 45./180*pi;
sigma_x = 300; 
sigma_y = 1000;
a = cos(theta)^2/2/sigma_x^2 + sin(theta)^2/2/sigma_y^2;
b = -sin(2*theta)/4/sigma_x^2 + sin(2*theta)/4/sigma_y^2 ;
c = sin(theta)^2/2/sigma_x^2 + cos(theta)^2/2/sigma_y^2;

for i=1:n1
    for j = 1:n2
        data_ed_pdf(i,j) = exp( - (a*(i-ic1).^2 + 2*b*(i-ic1).*(j-ic2) + c*(j-ic2).^2));
    end
end

theta = 0.;
sigma_x = 3; 
sigma_y = 300;
a = cos(theta)^2/2/sigma_x^2 + sin(theta)^2/2/sigma_y^2;
b = -sin(2*theta)/4/sigma_x^2 + sin(2*theta)/4/sigma_y^2 ;
c = sin(theta)^2/2/sigma_x^2 + cos(theta)^2/2/sigma_y^2;

for i=1:n3
    for j = 1:n1
        data_ve_pdf(i,j) = exp( - (a*(i-ic3).^2 + 2*b*(i-ic3).*(j-ic1) + c*(j-ic1).^2));
    end
end

theta = -0.3/180*pi;
sigma_x = 3; 
sigma_y = 1000;
a = cos(theta)^2/2/sigma_x^2 + sin(theta)^2/2/sigma_y^2;
b = -sin(2*theta)/4/sigma_x^2 + sin(2*theta)/4/sigma_y^2 ;
c = sin(theta)^2/2/sigma_x^2 + cos(theta)^2/2/sigma_y^2;

for i=1:n3
    for j = 1:n2
        data_vd_pdf(i,j) = exp( - (a*(i-ic3).^2 + 2*b*(i-ic3).*(j-ic2) + c*(j-ic2).^2));
    end
end

data_ed_pdf = data_ed_pdf ./ sum(sum(data_ed_pdf));
data_ve_pdf = data_ve_pdf ./ sum(sum(data_ve_pdf));
data_vd_pdf = data_vd_pdf ./ sum(sum(data_vd_pdf));

hf=figure(4);
subplot(2,3,4)
contour(nbin1,nbin3,data_ve_pdf,20)
% ylim([500 5000])
% xlim([0 0.5])
title('v_v - \epsilon pdf')
title('(d)')
xlabel('\epsilon')
ylabel('v_v')


subplot(2,3,5)
contour(nbin2,nbin3,data_vd_pdf,20)
% ylim([500 5000])
% xlim([0 0.2])
title('v_v - \delta pdf')
title('(e)')
xlabel('\delta')
ylabel('v_v')

subplot(2,3,6)
contour(nbin2,nbin1,data_ed_pdf,20)
%ylim([0 0.5])
%xlim([0 0.2])
title('\epsilon - \delta pdf')
title('(f)')
xlabel('\delta')
ylabel('\epsilon')

subplot(2,3,1)
imagesc(nbin1,nbin3,data_ve_pdf)
title('v_v - \epsilon pdf')
title('(a)')
axis xy
xlabel('\epsilon')
ylabel('v_v')

subplot(2,3,2)
imagesc(nbin2,nbin3,data_vd_pdf)
title('v_v - \delta pdf')
title('(b)')
axis xy
xlabel('\delta')
ylabel('v_v')

subplot(2,3,3)
imagesc(nbin2,nbin1,data_ed_pdf)
title('\epsilon - \delta pdf')
title('(c)')
%ylim([0 0.5])
%xlim([0 0.2])
axis xy
xlabel('\delta')
ylabel('\epsilon')
print(hf,'-dpdf',['/net/server/homes/sep/myfusan/Report/149-Rockphy/Fig/data-vnepsdel.pdf'])
%exit
