clear;clc; close all
addpath('/net/server/homes/sep/myfusan/Research/RockPhy/Matlab/');
addpath('/net/server/homes/sep/myfusan/Research/RockPhy/Matlab/subroutine/');

psand  = 101;
pfluid = 31;

% stiffness tensor of clay 
rho_clay = 2.4; vp_clay  = 4.94;
vs_clay  = 2.6; eps_clay = 1.02;
del_clay = 0.5; gam_clay = 1.68;
K_clay  = rho_clay*vp_clay*vp_clay; 
Mu_clay = rho_clay*vs_clay*vs_clay;
Lambda_clay = K_clay - 2*Mu_clay/3;
c11 = K_clay * (1+2*eps_clay); 
c33 = K_clay; 
c44 = Mu_clay;
c66 = Mu_clay * (1+2*gam_clay);
c12 = c11 - 2*c66;
c13 = K_clay * del_clay + K_clay - 2*Mu_clay;
C_clay=[c11,c12,c13,0,0,0;
    c12,c11,c13,0,0,0;
    c13,c13,c33,0,0,0;
     0, 0,  0,c44,0,0;
     0, 0,  0,0,c44,0;
     0, 0,  0,0,0,c66;];

% stiffness tensor of sand 
rho_sand = 2.65; vp_sand = 6.0; vs_sand=4.0;
K_sand  = rho_sand*vp_sand*vp_sand; 
Mu_sand = rho_sand*vs_sand*vs_sand;
Lambda_sand = K_sand - 2*Mu_sand/3;
c11 = Lambda_sand + 2*Mu_sand;
c44 = Mu_sand;
c12 = Lambda_sand;
C_sand=[c11,c12,c12,0,0,0;
    c12,c11,c12,0,0,0;
    c12,c12,c11,0,0,0;
     0, 0,  0,c44,0,0;
     0, 0,  0,0,c44,0;
     0, 0,  0,0,0,c44;];

[dc11,dc33,dc44,dc12,dc13,v1_frac,v2_frac]=dem_aniso(C_clay,C_sand,0.8,psand);

epsilon1 = (dc11-dc33)./(2*dc33);
delta1   = (dc13+dc44).^2 - (dc33-dc44).^2;
delta1   = delta1 ./ (2*dc33.*(dc33-dc44));

%% build the model at the well location
load sandyshale2
fid = fopen('/net/server/homes/sep/myfusan/Research/RockPhy/welllog/well2.vshale.H@','r','s');
vshale = fread(fid, inf,'*float');
%fid = fopen('/net/server/homes/sep/myfusan/Research/RockPhy/welllog/well2.phi.H@','r','s');
%phi = fread(fid, inf,'*float');

eps = zeros(size(vshale));
del = eps;

for i = 1:length(vshale)
    psand = (1 - vshale(i))*100;
    ids = floor(psand)+1;
    if (ids<1); ids=1; end
    if (ids>101); ids=101; end
%    pfld  = phi(i)*100;
%    idf = floor(pfld) + 1;
%    if (idf<1); idf=1; end
%    if (idf>31); idf=31; end
    
%    eps(i) = epsilon2(idf,ids); 
%    del(i) = abs(delta2  (idf,ids)); 
    eps(i) = epsilon1(ids); 
    del(i) = abs(delta1  (ids)); 
end

%% write out the modeled anisotropy at the well location
n1=25786; o1=299.618; d1=0.1524;

fid = fopen('sandyshale.eps.H','w');
fprintf(fid,'n1=%d o1=%f d1=%f ',n1,o1,d1);
fprintf(fid,'label1=depth(m)\n');
fprintf(fid,'n2=1 o2=0 d2=1\n');
fprintf(fid,'n3=1 o3=0 d3=1\n');
fprintf(fid,'in=./sandyshale.eps.H@');
fclose(fid);

fid = fopen('sandyshale.eps.H@','w','s');
count = fwrite(fid, eps,'real*4','s');
fclose(fid);

fid = fopen('sandyshale.del.H','w');
fprintf(fid,'n1=%d o1=%f d1=%f ',n1,o1,d1);
fprintf(fid,'label1=depth(m)\n');
fprintf(fid,'n2=1 o2=0 d2=1\n');
fprintf(fid,'n3=1 o3=0 d3=1\n');
fprintf(fid,'in=./sandyshale.del.H@');
fclose(fid);

fid = fopen('sandyshale.del.H@','w','s');
count = fwrite(fid, del,'real*4','s');
fclose(fid);