function [epsilon,delta]=dem_sandyshale(vshale,poro,pillite,W200_exp,W400_exp,phi_c,phi_d)

% compute parameters
phi_n = ceil(phi_c/phi_d+1);

%% Initialize the mineral property
rho = [2.4,   2.4,  2.65];       % g/cc
vp  = [3.075, 4.94, 6.0 ];       % km/s
vs  = [1.5,   2.6,  4.0 ];       % km/s
eps = [0.255, 1.02, 0.  ];
del = [0.,    0.5,  0.  ];
gam = [0.48, 1.68,  0.  ];

Cij = zeros(3,6);
for i = 1:3
    M  = rho(i) * vp(i) * vp(i);
    Nu = rho(i) * vs(i) * vs(i);
    Cij(i,1) = M*(1+2*eps(i));
    Cij(i,2) = M;
    Cij(i,3) = M*del(i) + M - 2*Nu;
    Cij(i,4) = Nu;
    Cij(i,5) = Nu * (1+2*gam(i));
    Cij(i,6) = Cij(i,1) - 2*Cij(i,5);
end

% compute the parameters for averaging
% only for clay and illite
% C11, C33, C13, C44, C66, C12
a1=zeros(2,1);a2=a1;a3=a1;la=a1;mu=a1;
for i = 1:2
    a1(i) = Cij(i,1) + Cij(i,2) - 2*Cij(i,3) - 4*Cij(i,4);
    a2(i) = Cij(i,1) - 3*Cij(i,6) + 2*Cij(i,3) - 2*Cij(i,4);
    a3(i) = 4*Cij(i,1) - 3*Cij(i,2) - Cij(i,3) - 2*Cij(i,4);
    la(i) = 1./15 * (Cij(i,1)+Cij(i,2)+5*Cij(i,6)+8*Cij(i,3)-4*Cij(i,4));
    mu(i) = 1./30 * (7*Cij(i,1)+2*Cij(i,2)-5*Cij(i,6)-4*Cij(i,3)+12*Cij(i,4));
end

% compute the orientation distribution function
W200=zeros(phi_n,1);
W400=zeros(phi_n,1);
W000	   = sqrt(0.5) / (4*pi*pi);
W200_max = sqrt(2.5) / (4*pi*pi);
W400_max = sqrt(4.5) / (4*pi*pi);
for i=1:phi_n
    phi = (i-1)*phi_d;
    W200(i) = W200_max*(1-phi/phi_c)^W200_exp;
    W400(i) = W400_max*(1-phi/phi_c)^W400_exp;
end

% average stiffness tensor
aC11 = zeros(3,1);
aC33 = zeros(3,1);
aC13 = zeros(3,1);
aC44 = zeros(3,1);
aC66 = zeros(3,1);
aC12 = zeros(3,1);

% for sand is the same
aC11(3) = Cij(3,1);
aC33(3) = Cij(3,2);
aC13(3) = Cij(3,3);
aC44(3) = Cij(3,4);
aC66(3) = Cij(3,5);
aC12(3) = Cij(3,6);
C_sand=[aC11(3),aC12(3),aC13(3),0,0,0;
    aC12(3),aC11(3),aC12(3),0,0,0;
    aC13(3),aC12(3),aC11(3),0,0,0;
    0, 0,  0,aC44(3),0,0;
    0, 0,  0,0,aC44(3),0;
    0, 0,  0,0,0,aC66(3);];
% compute the average stiffness tensor after ODF

ndepth = length(vshale);
epsilon = zeros(ndepth,1);
delta   = epsilon;
%%
for id = 1:ndepth
    iphi = ceil(poro(id)/phi_d + 1);
    for i = 1:2
        aC11(i) = la(i) + 2*mu(i) + 4 *sqrt(2.)/105*pi*pi* (2*sqrt(5.)*a3(i)*W200(iphi) +  3*a1(i)*W400(iphi));
        aC33(i) = la(i) + 2*mu(i) - 16*sqrt(2.)/105*pi*pi* (  sqrt(5.)*a3(i)*W200(iphi) -  2*a1(i)*W400(iphi));
        aC12(i) = la(i) - 4*sqrt(2.)/315*pi*pi* (2*sqrt(5.)*( 7*a2(i)-a3(i))*W200(iphi) -  3*a1(i)*W400(iphi));
        aC13(i) = la(i) + 4*sqrt(2.)/315*pi*pi* (  sqrt(5.)*( 7*a2(i)-a3(i))*W200(iphi) - 12*a1(i)*W400(iphi));
        aC44(i) = mu(i) - 2*sqrt(2.)/315*pi*pi* (  sqrt(5.)*( 7*a2(i)+a3(i))*W200(iphi) + 24*a1(i)*W400(iphi));
        aC66(i) = (aC11(i) - aC12(i))/2.;
    end
    
    aC11_sh = (1-pillite(id))*aC11(1) + pillite(id)*aC11(2);
    aC33_sh = (1-pillite(id))*aC33(1) + pillite(id)*aC33(2);
    aC13_sh = (1-pillite(id))*aC13(1) + pillite(id)*aC13(2);
    aC12_sh = (1-pillite(id))*aC12(1) + pillite(id)*aC12(2);
    aC44_sh = (1-pillite(id))*aC44(1) + pillite(id)*aC44(2);
    aC66_sh = (1-pillite(id))*aC66(1) + pillite(id)*aC66(2);
    
    C_sh=[aC11_sh,aC12_sh,aC13_sh,0,0,0;
        aC12_sh,aC11_sh,aC13_sh,0,0,0;
        aC13_sh,aC13_sh,aC33_sh,0,0,0;
        0, 0,  0,aC44_sh,0,0;
        0, 0,  0,0,aC44_sh,0;
        0, 0,  0,0,0,aC66_sh;];
    
    psand = 1 - vshale(id);
    %psand = min(ceil(psand * 100),50);
    clear dc11 dc33 dc44 dc12 dc13 v1_frac v2_frac
    
    [dc11,dc33,dc44,dc12,dc13,v1_frac,v2_frac]=dem_aniso(C_sh,C_sand,0.8,psand);
    
    epsilon(id) = (dc11(end)-dc33(end))./(2*dc33(end));
    delta(id)   = (dc13(end)+dc44(end)).^2 - (dc33(end)-dc44(end)).^2;
    delta(id)   = delta(id) ./ (2*dc33(end).*(dc33(end)-dc44(end)));
end
end